/* $Id: guppi-stat-init.c,v 1.6 2000/10/20 01:21:49 trow Exp $ */

/*
 * guppi-stat-init.c
 *
 * Copyright (C) 2000 EMC Capital Management, Inc.
 *
 * Developed by Jon Trowbridge <trow@gnu.org>.

 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#include <config.h>
#include <guppi-guile.h>
#include "guppi-scm-stat.h"
#include "guppi-stat-init.h"

#ifdef HAVE_PYTHON
#include "guppi-python-stat.h"
#endif

void
guppi_stat_init (void)
{
  if (guppi_guile_is_active ())
    guppi_scm_stat_init ();

#ifdef HAVE_PYTHON
  guppi_python_stat_init ();
#endif
}


/* $Id: guppi-stat-init.c,v 1.6 2000/10/20 01:21:49 trow Exp $ */
